from distutils.core import setup
from distutils.extension import Extension
from Cython.Distutils import build_ext

# You simply have to include the libraries in the ext_modules
# If the library is not found you can give the paths, e.g.:
#
#    include_gsl_dir = "/usr/local/include/"
#    lib_gsl_dir = "/usr/local/lib/"
#    ext_modules = [Extension("bessel_gsl", 
#                             ["bessel_gsl_module.pyx"],
#                             include_dirs=[include_gsl_dir],
#                             library_dirs=[lib_gsl_dir],
#                             libraries=["gsl","gslcblas"])]
#     

ext_modules = [Extension("bessel_gsl", 
               ["bessel_gsl_module.pyx"],
               libraries=["gsl","gslcblas"])]
setup(cmdclass={'build_ext': build_ext},ext_modules= ext_modules)

